@@ -22,7 +22,9 @@
 
 #include "SettingsPage.h"
 
+class QButtonGroup;
 class QCheckBox;
+class QRadioButton;
 
 class GeneralOptionsPage : public SettingsPage
 {
@@ -34,8 +36,8 @@ class GeneralOptionsPage : public SettingsPage
 
     public Q_SLOTS:
 
-    void saveChanges() Q_DECL_OVERRIDE;
-    void resetChanges() Q_DECL_OVERRIDE;
+    void saveChanges() override;
+    void resetChanges() override;
 
     private Q_SLOTS:
 
@@ -43,9 +45,12 @@ class GeneralOptionsPage : public SettingsPage
 
     private:
 
-    QCheckBox *mRememberRect;
+    QButtonGroup* mPrintKeyActionGroup;
+    QRadioButton* mRememberAlways;
+    QRadioButton* mRememberUntilClosed;
     QCheckBox *mUseLightBackground;
     QCheckBox *mShowMagnifier;
+    QCheckBox *mReleaseToCapture;
 };
 
 #endif // GENERALOPTIONSPAGE_H
